==> python2-eric-18.01-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/eric6/Plugins/UiExtensionPlugins/Translator/TranslatorEngines/YandexEngine.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Yandex translation engine.
"""

from __future__ import unicode_literals
try:
    str = unicode
except NameError:
    pass

import json

from PyQt5.QtCore import QUrl, QByteArray

import Utilities

from .TranslationEngine import TranslationEngine


class YandexEngine(TranslationEngine):
    """
    Class implementing the translation engine for the Yandex
    translation service.
    """
    TranslatorUrl = "https://translate.yandex.net/api/v1.5/tr.json/translate"
    TranslatorLimit = 10000
    
    def __init__(self, plugin, parent=None):
        """
        Constructor
        
        @param plugin reference to the plugin object (TranslatorPlugin)
        @param parent reference to the parent object (QObject)
        """
        super(YandexEngine, self).__init__(plugin, parent)
        
        self.__errors = {
            401: self.tr("Invalid API key."),
            402: self.tr("API key has been blocked."),
            403: self.tr("Daily limit for requests has been reached."),
            404: self.tr("Daily limit for the volume of translated text"
                         " reached."),
            413: self.tr("Text size exceeds the maximum."),
            422: self.tr("Text could not be translated."),
            501: self.tr("The specified translation direction is not"
                         " supported."),
        }
    
    def engineName(self):
        """
        Public method to return the name of the engine.
        
        @return engine name (string)
        """
        return "yandex"
    
    def supportedLanguages(self):
        """
        Public method to get the supported languages.
        
        @return list of supported language codes (list of string)
        """
        return ["ar", "be", "bg", "bs", "ca", "cs", "da", "de", "el", "en",
                "es", "et", "fi", "fr", "ga", "gl", "hi", "hr", "hu", "id",
                "is", "it", "iw", "ja", "ka", "ko", "lt", "lv", "mk", "mt",
                "nl", "no", "pl", "pt", "ro", "ru", "sk", "sl", "sq", "sr",
                "sv", "th", "tl", "tr", "uk", "vi", "zh-CN", "zh-TW",
                ]
    
    def getTranslation(self, requestObject, text, originalLanguage,
                       translationLanguage):
        """
        Public method to translate the given text.
        
        @param requestObject reference to the request object
            (TranslatorRequest)
        @param text text to be translated (string)
        @param originalLanguage language code of the original (string)
        @param translationLanguage language code of the translation (string)
        @return tuple of translated text (string) and flag indicating
            success (boolean)
        """
        if len(text) > self.TranslatorLimit:
            return (self.tr("Only texts up to {0} characters are allowed.")
                    .format(self.TranslatorLimit), False)
        
        apiKey = self.plugin.getPreferences("YandexKey")
        if not apiKey:
            return self.tr("A valid Yandex key is required."), False
        
        params = QByteArray(
            "key={0}&lang={1}-{2}&text=".format(
                apiKey, originalLanguage, translationLanguage).encode("utf-8"))
        encodedText = QByteArray(Utilities.html_encode(text).encode("utf-8"))\
            .toPercentEncoding()
        request = params + encodedText
        response, ok = requestObject.post(QUrl(self.TranslatorUrl), request)
        if ok:
            try:
                responseDict = json.loads(response)
            except ValueError:
                return self.tr("Invalid response received"), False
            
            if responseDict["code"] != 200:
                try:
                    error = self.__errors[responseDict["code"]]
                except KeyError:
                    error = self.tr("Unknown error code ({0}) received.")\
                        .format(responseDict["code"])
                return error, False
            
            sentences = responseDict["text"]
            result = ""
            for sentence in sentences:
                result += sentence.replace("\n", "<br/>")
        else:
            result = response
        return result, ok

==> python2-eric-18.08-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/eric6/Plugins/UiExtensionPlugins/Translator/TranslatorEngines/YandexEngine.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Yandex translation engine.
"""

from __future__ import unicode_literals
try:
    str = unicode
except NameError:
    pass

import json

from PyQt5.QtCore import QUrl, QByteArray, QTimer

import Utilities

from .TranslationEngine import TranslationEngine


class YandexEngine(TranslationEngine):
    """
    Class implementing the translation engine for the Yandex
    translation service.
    """
    TranslatorUrl = "https://translate.yandex.net/api/v1.5/tr.json/translate"
    TranslatorLimit = 10000
    
    def __init__(self, plugin, parent=None):
        """
        Constructor
        
        @param plugin reference to the plugin object (TranslatorPlugin)
        @param parent reference to the parent object (QObject)
        """
        super(YandexEngine, self).__init__(plugin, parent)
        
        self.__errors = {
            401: self.tr("Invalid API key."),
            402: self.tr("API key has been blocked."),
            403: self.tr("Daily limit for requests has been reached."),
            404: self.tr("Daily limit for the volume of translated text"
                         " reached."),
            413: self.tr("Text size exceeds the maximum."),
            422: self.tr("Text could not be translated."),
            501: self.tr("The specified translation direction is not"
                         " supported."),
        }
        
        QTimer.singleShot(0, self.availableTranslationsLoaded.emit)
    
    def engineName(self):
        """
        Public method to return the name of the engine.
        
        @return engine name (string)
        """
        return "yandex"
    
    def supportedLanguages(self):
        """
        Public method to get the supported languages.
        
        @return list of supported language codes (list of string)
        """
        return ["ar", "be", "bg", "bs", "ca", "cs", "da", "de", "el", "en",
                "es", "et", "fi", "fr", "ga", "gl", "hi", "hr", "hu", "id",
                "is", "it", "iw", "ja", "ka", "ko", "lt", "lv", "mk", "mt",
                "nl", "no", "pl", "pt", "ro", "ru", "sk", "sl", "sq", "sr",
                "sv", "th", "tl", "tr", "uk", "vi", "zh-CN", "zh-TW",
                ]
    
    def getTranslation(self, requestObject, text, originalLanguage,
                       translationLanguage):
        """
        Public method to translate the given text.
        
        @param requestObject reference to the request object
            (TranslatorRequest)
        @param text text to be translated (string)
        @param originalLanguage language code of the original (string)
        @param translationLanguage language code of the translation (string)
        @return tuple of translated text (string) and flag indicating
            success (boolean)
        """
        if len(text) > self.TranslatorLimit:
            return (self.tr("Only texts up to {0} characters are allowed.")
                    .format(self.TranslatorLimit), False)
        
        apiKey = self.plugin.getPreferences("YandexKey")
        if not apiKey:
            return self.tr("A valid Yandex key is required."), False
        
        params = QByteArray(
            "key={0}&lang={1}-{2}&text=".format(
                apiKey, originalLanguage, translationLanguage).encode("utf-8"))
        encodedText = QByteArray(Utilities.html_encode(text).encode("utf-8"))\
            .toPercentEncoding()
        request = params + encodedText
        response, ok = requestObject.post(QUrl(self.TranslatorUrl), request)
        if ok:
            try:
                responseDict = json.loads(response)
            except ValueError:
                return self.tr("Invalid response received"), False
            
            if responseDict["code"] != 200:
                try:
                    error = self.__errors[responseDict["code"]]
                except KeyError:
                    error = self.tr("Unknown error code ({0}) received.")\
                        .format(responseDict["code"])
                return error, False
            
            sentences = responseDict["text"]
            result = ""
            for sentence in sentences:
                result += sentence.replace("\n", "<br/>")
        else:
            result = response
        return result, ok
